@@ -47,8 +47,8 @@ def main():
 
     while True:
         try:
-            # file = '/www/server/panel/class/panelPlugin.py'
-            file = '/Users/zhao/githubs/nginx_manage/12.py'
+            file = '/www/server/panel/plugin/total/total_main.py'
+            # file = '/Users/zhao/githubs/nginx_manage/12.py'
         except:
             print('需要安装付费插件')
             time.sleep(10)
